### Name: studentGrowthProjections
### Title: Student Growth Projections
### Aliases: studentGrowthProjections
### Keywords: misc models

### ** Examples

###########################################################################
####
#### Code for master file which computes percentile growth 
#### projections/trajectories associated with 2004 to 2006
#### data using provided sgpData
####
########################################################################### 

###
### Establish and Save Reading Cut Scores
###

if (is.na(file.info("Cutscores")$isdir)) {
    dir.create("Cutscores")
}

cutscores_read_g3 <- c(465.5, 525.5, 655.5)
cutscores_read_g4 <- c(516.5, 571.5, 670.5)
cutscores_read_g5 <- c(537.5, 587.5, 690.5)
cutscores_read_g6 <- c(542.5, 599.5, 695.5)
cutscores_read_g7 <- c(566.5, 619.5, 715.5)

save(cutscores_read_g3, file="Cutscores/cutscores_read_g3.Rdata")
save(cutscores_read_g4, file="Cutscores/cutscores_read_g4.Rdata")
save(cutscores_read_g5, file="Cutscores/cutscores_read_g5.Rdata")
save(cutscores_read_g6, file="Cutscores/cutscores_read_g6.Rdata")
save(cutscores_read_g7, file="Cutscores/cutscores_read_g7.Rdata")

###
### Load Data
###

data(sgpData)

###
### Create subset of data for 2004 to 2006
###

attach(sgpData)
sgpData <- data.frame(ID, GRADE_04, GRADE_05, GRADE_06, SS_04, SS_05, SS_06)
detach(sgpData)

###
### Submit to Growth Projection Function
###

##
## 333333333333333333333333333333333333333333333333333333333
##

##
## 3rd graders receiving projections
##

sgp_g2s_read_2007_g3 <- studentGrowthProjections(
             student.data = sgpData,
             num.panels = 3,
             max.num.scores = 1,
             num.prior.scores=list(c(1,2,3)),
             proj.function.labels = list(my.year=2007, my.subject="read", my.grade=3),
             subset.grade = 3,
             percentile.trajectories=c(35,65),
             projcuts.digits=0)

## save(sgp_g2s_read_2007_g3, file="Results_Data/sgp_g2s_read_2007_g3.Rdata")

##
## 444444444444444444444444444444444444444444444444444444444
##

sgp_g2s_read_2007_g4 <- studentGrowthProjections(
             student.data = sgpData,
             num.panels = 3,
             max.num.scores = 2,
             num.prior.scores=list(c(1,2,3), c(2,3,3)),
             proj.function.labels = list(my.year=2007, my.subject="read", my.grade=4),
             subset.grade = 4,
             percentile.trajectories=c(35,65),
             projcuts.digits=0)

## save(sgp_g2s_read_2007_g4, file="Results_Data/sgp_g2s_read_2007_g4.Rdata")


##
## 555555555555555555555555555555555555555555555555555555555555
## 

sgp_g2s_read_2007_g5 <- studentGrowthProjections(
             student.data = sgpData,
             num.panels = 3,
             max.num.scores = 3,
             num.prior.scores=list(c(1,2,NA), c(2,3,NA), c(3,3,NA)),
             proj.function.labels = list(my.year=2007, my.subject="read", my.grade=5),
             subset.grade = 5,
             percentile.trajectories=c(35,65),
             projcuts.digits=0)

## save(sgp_g2s_read_2007_g5, file="Results_Data/sgp_g2s_read_2007_g5.Rdata")

##
## 66666666666666666666666666666666666666666666666666666666666
##

sgp_g2s_read_2007_g6 <- studentGrowthProjections(
             student.data = sgpData,
             num.panels = 3,
             max.num.scores = 3,
             num.prior.scores=list(c(1,NA,NA), c(2,NA,NA), c(3,NA,NA)),
             proj.function.labels = list(my.year=2007, my.subject="read", my.grade=6),
             subset.grade = 6,
             percentile.trajectories=c(35,65),
             projcuts.digits=0)

## save(sgp_g2s_read_2007_g6, file="Results_Data/sgp_g2s_read_2007_g6.Rdata")

###
### Combine all the different grade growth projection files into a single file 
### and write the results to a comma separated data set
###

sgp_g2s_read_2007_gall <- rbind(sgp_g2s_read_2007_g3,
                                sgp_g2s_read_2007_g4,
                                sgp_g2s_read_2007_g5,
                                sgp_g2s_read_2007_g6)

save(sgp_g2s_read_2007_gall, file="Results_Data/sgp_g2s_read_2007_gall.Rdata")
write.table(sgp_g2s_read_2007_gall, file="Results_Data/sgp_g2s_read_2007_gall.dat", 
            sep=" , ", row.names=FALSE, quote=FALSE)


###
### End of Master Program for Percentile Growth Projections/Trajectories
###



